@@ -77,6 +77,7 @@ void     tracker_data_insert_statement_with_string  (const gchar               *
                                                      const gchar               *object,
                                                      GError                   **error);
 void     tracker_data_begin_transaction             (void);
+void     tracker_data_begin_replay_transaction      (time_t                     time);
 void     tracker_data_commit_transaction            (void);
 void     tracker_data_update_sparql                 (const gchar               *update,
                                                      GError                   **error);
@@ -85,6 +86,8 @@ tracker_data_update_sparql_blank           (const gchar               *update,
                                             GError                   **error);
 void     tracker_data_update_buffer_flush           (GError                   **error);
 
+void     tracker_data_sync                          (void);
+
 /* Volume handling */
 void     tracker_data_update_enable_volume          (const gchar               *udi,
                                                      const gchar               *mount_path);
