@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2009, Nokia (urho.konttori@nokia.com)
  *
@@ -60,7 +59,7 @@ typedef struct {
 
 typedef struct {
 	GMainLoop *main_loop;
-	gboolean value;
+	gchar *iri;
 } SparqlQueryData;
 
 typedef struct {
@@ -114,6 +113,10 @@ struct TrackerMinerFSPrivate {
 	guint           directories_ignored;
 	guint           files_found;
 	guint           files_ignored;
+
+	guint           total_files_processed;
+	guint           total_files_notified;
+	guint           total_files_notified_error;
 };
 
 enum {
@@ -772,6 +775,10 @@ process_print_stats (TrackerMinerFS *fs)
 		           fs->private->total_files_ignored);
 		g_message ("Total monitors    : %d",
 		           tracker_monitor_get_count (fs->private->monitor));
+		g_message ("Total files processed : %d (%d notified, %d with error)\n",
+			   fs->private->total_files_processed,
+			   fs->private->total_files_notified,
+			   fs->private->total_files_notified_error);
 		g_message ("--------------------------------------------------\n");
 	}
 }
@@ -900,9 +907,14 @@ sparql_query_cb (GObject      *object,
 		g_error_free (error);
 	}
 
-	data->value = query_results && query_results->len == 1;
-	g_main_loop_quit (data->main_loop);
+	if (query_results && query_results->len == 1) {
+		gchar **val;
 
+		val = g_ptr_array_index (query_results, 0);
+		data->iri = g_strdup (val[0]);
+	}
+
+        g_main_loop_quit (data->main_loop);
 }
 
 static void
@@ -970,29 +982,35 @@ item_add_or_update (TrackerMinerFS *fs,
 	               &processing);
 
 	if (!processing) {
+		gchar *uri;
+
+		uri = g_file_get_uri (file);
+
 		/* Re-fetch data, since it might have been
 		 * removed in broken implementations
 		 */
 		data = process_data_find (fs, file);
 
-		if (!data) {
-			gchar *uri;
+		g_message ("%s refused to process '%s'", G_OBJECT_TYPE_NAME (fs), uri);
 
-			uri = g_file_get_uri (file);
+		if (!data) {
 			g_critical ("%s has returned FALSE in ::process-file for '%s', "
 			            "but it seems that this file has been processed through "
 			            "tracker_miner_fs_notify_file(), this is an "
 			            "implementation error", G_OBJECT_TYPE_NAME (fs), uri);
-			g_free (uri);
 		} else {
 			priv->processing_pool = g_list_remove (priv->processing_pool, data);
 			process_data_free (data);
 		}
+
+		g_free (uri);
 	} else {
 		guint length;
 
 		length = g_list_length (priv->processing_pool);
 
+		fs->private->total_files_processed++;
+
 		if (length >= priv->pool_limit) {
 			retval = FALSE;
 		}
@@ -1006,19 +1024,18 @@ item_add_or_update (TrackerMinerFS *fs,
 }
 
 static gboolean
-item_query_exists (TrackerMinerFS *miner,
-                   GFile          *file)
+item_query_exists (TrackerMinerFS  *miner,
+                   GFile           *file,
+                   gchar          **iri)
 {
 	gboolean   result;
 	gchar     *sparql, *uri;
-	SparqlQueryData data;
+	SparqlQueryData data = { 0 };
 
 	uri = g_file_get_uri (file);
-	sparql = g_strdup_printf ("SELECT ?s WHERE { ?s a rdfs:Resource . FILTER (?s = <%s>) }",
-	                          uri);
+	sparql = g_strdup_printf ("SELECT ?s WHERE { ?s nie:url '%s' }", uri);
 
 	data.main_loop = g_main_loop_new (NULL, FALSE);
-	data.value = FALSE;
 
 	tracker_miner_execute_sparql (TRACKER_MINER (miner),
 	                              sparql,
@@ -1027,10 +1044,16 @@ item_query_exists (TrackerMinerFS *miner,
 	                              &data);
 
 	g_main_loop_run (data.main_loop);
-	result = data.value;
+	result = (data.iri != NULL);
 
 	g_main_loop_unref (data.main_loop);
 
+	if (iri) {
+		*iri = data.iri;
+	} else {
+		g_free (data.iri);
+	}
+
 	g_free (sparql);
 	g_free (uri);
 
@@ -1050,7 +1073,7 @@ item_remove (TrackerMinerFS *fs,
 	g_debug ("Removing item: '%s' (Deleted from filesystem)",
 	         uri);
 
-	if (!item_query_exists (fs, file)) {
+	if (!item_query_exists (fs, file, NULL)) {
 		g_debug ("  File does not exist anyway (uri:'%s')", uri);
 		g_free (uri);
 		return TRUE;
@@ -1066,14 +1089,22 @@ item_remove (TrackerMinerFS *fs,
 
 	/* Delete all children */
 	g_string_append_printf (sparql,
-	                        "DELETE FROM <%s> { ?u a rdfs:Resource } "
-	                        "WHERE { ?u nfo:belongsToContainer ?p . FILTER (fn:starts-with (?p, \"%s\")) } ",
-	                        uri, slash_uri);
+	                        "DELETE { "
+	                        "  ?child a rdfs:Resource "
+	                        "} WHERE {"
+	                        "  ?child nie:url ?u . "
+	                        "  FILTER (fn:starts-with (?u, '%s')) "
+	                        "}",
+	                        slash_uri);
 
 	/* Delete resource itself */
 	g_string_append_printf (sparql,
-	                        "DELETE FROM <%s> { <%s> a rdfs:Resource }",
-	                        uri, uri);
+	                        "DELETE { "
+	                        "  ?u a rdfs:Resource "
+	                        "} WHERE { "
+	                        "  ?u nie:url '%s' "
+	                        "}",
+	                        uri);
 
 	data = process_data_new (file, NULL, NULL);
 	fs->private->processing_pool = g_list_prepend (fs->private->processing_pool, data);
@@ -1134,7 +1165,7 @@ item_writeback (TrackerMinerFS *fs,
 
 	g_debug ("Updating item: '%s' (Writeback event)", uri);
 
-	if (!item_query_exists (fs, working_file)) {
+	if (!item_query_exists (fs, working_file, NULL)) {
 		g_debug ("  File does not exist anyway (uri:'%s')", uri);
 		return TRUE;
 	}
@@ -1153,19 +1184,19 @@ item_writeback (TrackerMinerFS *fs,
 		/* Perhaps we should move the DELETE to tracker-miner-files.c?
 		 * Or we add support for DELETE to TrackerSparqlBuilder ofcrs */
 
-		query = g_strdup_printf ("DELETE FROM <%s> { <%s> "
-		                         "nfo:fileSize ?unknown1 ;\n\t"
-		                         "nfo:fileLastModified ?unknown2 ;\n\t"
-		                         "nfo:fileLastAccessed ?unknown3 ;\n\t"
-		                         "nie:mimeType ?unknown4 \n"
-		                         "} WHERE { <%s> "
-		                         "nfo:fileSize ?unknown1 ;\n\t"
-		                         "nfo:fileLastModified ?unknown2 ;\n\t"
-		                         "nfo:fileLastAccessed ?unknown3 ;\n\t"
-		                         "nie:mimeType ?unknown4 \n"
-		                         "} \n %s",
-		                         uri, uri, uri,
-		                         tracker_sparql_builder_get_result (sparql));
+		query = g_strdup_printf ("DELETE { "
+		                         "  ?u nfo:fileSize ?unknown1 ; "
+		                         "     nfo:fileLastModified ?unknown2 ; "
+		                         "     nfo:fileLastAccessed ?unknown3 ; "
+		                         "     nie:mimeType ?unknown4 "
+		                         "} WHERE { "
+		                         "  ?u nfo:fileSize ?unknown1 ; "
+		                         "     nfo:fileLastModified ?unknown2 ; "
+		                         "     nfo:fileLastAccessed ?unknown3 ; "
+		                         "     nie:mimeType ?unknown4 ; "
+		                         "     nie:url '%s' "
+		                         "} %s",
+		                         uri, tracker_sparql_builder_get_result (sparql));
 
 		tracker_miner_execute_batch_update (TRACKER_MINER (fs),
 		                                    query,
@@ -1243,9 +1274,20 @@ item_update_uri_recursively (TrackerMinerFS    *fs,
 
 	move_data->level++;
 
-	g_string_append_printf (move_data->sparql, " <%s> tracker:uri <%s> .", source_uri, uri);
+	g_string_append_printf (move_data->sparql,
+	                        "INSERT { "
+	                        "  ?u nie:url '%s' "
+	                        "} WHERE { "
+	                        "  ?u nie:url '%s' "
+	                        "} ",
+	                        uri, source_uri);
+
+	sparql = g_strdup_printf ("SELECT ?child WHERE { "
+	                          "  ?child nfo:belongsToContainer ?c . "
+	                          "  ?c nie:url '%s' "
+	                          "}",
+                                  source_uri);
 
-	sparql = g_strdup_printf ("SELECT ?child WHERE { ?child nfo:belongsToContainer <%s> }", source_uri);
 	tracker_miner_execute_sparql (TRACKER_MINER (fs),
 	                              sparql,
 	                              NULL,
@@ -1264,12 +1306,13 @@ item_move (TrackerMinerFS *fs,
 	GString   *sparql;
 	RecursiveMoveData move_data;
 	ProcessData *data;
+	gchar *source_iri;
 
 	uri = g_file_get_uri (file);
 	source_uri = g_file_get_uri (source_file);
 
 	/* Get 'source' ID */
-	if (!item_query_exists (fs, source_file)) {
+	if (!item_query_exists (fs, source_file, &source_iri)) {
 		gboolean retval;
 
 		g_message ("Source file '%s' not found in store to move, indexing '%s' from scratch", source_uri, uri);
@@ -1306,13 +1349,25 @@ item_move (TrackerMinerFS *fs,
 	sparql = g_string_new ("");
 
 	g_string_append_printf (sparql,
-	                        "DELETE FROM <%s> { <%s> nfo:fileName ?o } WHERE { <%s> nfo:fileName ?o }",
-	                        source_uri, source_uri, source_uri);
-
-	g_string_append_printf (sparql, " INSERT INTO <%s> {", uri);
+	                        "DELETE FROM <%s> { "
+	                        "  <%s> nfo:fileName ?f ; "
+	                        "       nie:url ?u "
+	                        "} WHERE { "
+	                        "  <%s> nfo:fileName ?f ; "
+	                        "       nie:url ?u "
+	                        "} ",
+	                        source_iri, source_iri, source_iri);
 
 	escaped_filename = g_strescape (g_file_info_get_display_name (file_info), NULL);
-	g_string_append_printf (sparql, " <%s> nfo:fileName \"%s\" .", source_uri, escaped_filename);
+
+	g_string_append_printf (sparql,
+	                        "INSERT INTO <%s> {"
+	                        "  <%s> nfo:fileName '%s' ; "
+	                        "       nie:url '%s' "
+	                        "} ",
+	                        source_iri, source_iri,
+	                        escaped_filename, uri);
+
 	g_free (escaped_filename);
 
 	move_data.main_loop = g_main_loop_new (NULL, FALSE);
@@ -1327,8 +1382,6 @@ item_move (TrackerMinerFS *fs,
 
 	g_main_loop_unref (move_data.main_loop);
 
-	g_string_append (sparql, " }");
-
 	data = process_data_new (file, NULL, NULL);
 	fs->private->processing_pool = g_list_prepend (fs->private->processing_pool, data);
 
@@ -1342,6 +1395,7 @@ item_move (TrackerMinerFS *fs,
 	g_free (source_uri);
 	g_object_unref (file_info);
 	g_string_free (sparql, TRUE);
+	g_free (source_iri);
 
 	return TRUE;
 }
@@ -1592,7 +1646,7 @@ should_change_index_for_file (TrackerMinerFS *fs,
 	time_t              mtime;
 	struct tm           t;
 	gchar              *query, *uri;
-	SparqlQueryData     data;
+	SparqlQueryData     data = { 0 };
 
 	file_info = g_file_query_info (file,
 	                               G_FILE_ATTRIBUTE_TIME_MODIFIED,
@@ -1614,7 +1668,10 @@ should_change_index_for_file (TrackerMinerFS *fs,
 
 	gmtime_r (&mtime, &t);
 
-	query = g_strdup_printf ("SELECT ?file { ?file nfo:fileLastModified \"%04d-%02d-%02dT%02d:%02d:%02dZ\" . FILTER (?file = <%s>) }",
+	query = g_strdup_printf ("SELECT ?file { "
+	                         "  ?file nfo:fileLastModified \"%04d-%02d-%02dT%02d:%02d:%02dZ\" . "
+	                         "  ?file nie:url \"%s\""
+	                         "}",
 	                         t.tm_year + 1900,
 	                         t.tm_mon + 1,
 	                         t.tm_mday,
@@ -1624,7 +1681,6 @@ should_change_index_for_file (TrackerMinerFS *fs,
 	                         uri);
 
 	data.main_loop = g_main_loop_new (NULL, FALSE);
-	data.value = FALSE;
 
 	tracker_miner_execute_sparql (TRACKER_MINER (fs),
 	                              query,
@@ -1633,9 +1689,10 @@ should_change_index_for_file (TrackerMinerFS *fs,
 	                              &data);
 
 	g_main_loop_run (data.main_loop);
-	uptodate = data.value;
+	uptodate = (data.iri != NULL);
 
 	g_main_loop_unref (data.main_loop);
+	g_free (data.iri);
 	g_free (query);
 	g_free (uri);
 
@@ -1827,7 +1884,7 @@ monitor_item_moved_cb (TrackerMonitor *monitor,
 		path = g_file_get_path (file);
 		other_path = g_file_get_path (other_file);
 
-		source_stored = item_query_exists (fs, file);
+		source_stored = item_query_exists (fs, file, NULL);
 		should_process_other = should_check_file (fs, other_file, is_directory);
 
 		g_debug ("%s:'%s'->'%s':%s (%s) (move monitor event or user request)",
@@ -2120,6 +2177,42 @@ tracker_miner_fs_add_directory (TrackerMinerFS *fs,
 	crawl_directories_start (fs);
 }
 
+/**
+ * tracker_miner_fs_add_file:
+ * @fs: a #TrackerMinerFS
+ * @file: #GFile for the file to inspect
+ *
+ * Tells the filesystem miner to inspect a file.
+ **/
+void
+tracker_miner_fs_add_file (TrackerMinerFS *fs,
+                           GFile          *file)
+{
+	gboolean should_process;
+	gchar *path;
+
+	g_return_if_fail (TRACKER_IS_MINER_FS (fs));
+	g_return_if_fail (G_IS_FILE (file));
+
+	should_process = should_check_file (fs, file, FALSE);
+
+	path = g_file_get_path (file);
+
+	g_debug ("%s:'%s' (FILE) (requested by application)",
+	         should_process ? "Found " : "Ignored",
+	         path);
+
+	if (should_process) {
+		g_queue_push_tail (fs->private->items_updated,
+		                   g_object_ref (file));
+
+		item_queue_handlers_set_up (fs);
+	}
+
+	g_free (path);
+}
+
+
 static void
 check_files_removal (GQueue *queue,
                      GFile  *parent)
@@ -2293,6 +2386,12 @@ tracker_miner_fs_notify_file (TrackerMinerFS *fs,
 	g_return_if_fail (TRACKER_IS_MINER_FS (fs));
 	g_return_if_fail (G_IS_FILE (file));
 
+	fs->private->total_files_notified++;
+
+	if (error) {
+		fs->private->total_files_notified_error++;
+	}
+
 	data = process_data_find (fs, file);
 
 	if (!data) {
