@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2008-2009, Nokia
@@ -45,13 +44,13 @@
 #endif
 
 #include <libtracker-common/tracker-file-utils.h>
-#include <libtracker-common/tracker-statement-list.h>
 #include <libtracker-common/tracker-ontology.h>
 #include <libtracker-common/tracker-utils.h>
 #include <libtracker-common/tracker-type-utils.h>
 
+#include <libtracker-extract/tracker-extract.h>
+
 #include "tracker-albumart.h"
-#include "tracker-main.h"
 #include "tracker-dbus.h"
 
 /* We mmap the beginning of the file and read separately the last 128
@@ -173,7 +172,7 @@ typedef struct {
 	id3v2tag id3v24;
 } MP3Data;
 
-static void extract_mp3 (const gchar           *filename,
+static void extract_mp3 (const gchar           *uri,
                          TrackerSparqlBuilder  *metadata);
 
 enum {
@@ -1928,17 +1927,6 @@ extract_mp3 (const gchar          *uri,
 	audio_offset = parse_id3v2 (buffer, buffer_size, &md.id3v1, uri, metadata, &md);
 
 	md.title = tracker_coalesce (4, md.id3v24.title2, md.id3v23.title2, md.id3v22.title2, md.id3v1.title);
-	if (!md.title) {
-		gchar *p;
-
-		/* use filename */
-		md.title = g_filename_display_basename (filename);
-
-		p = strrchr (md.title, '.');
-		if (p) {
-			*p = '\0';
-		}
-	}
 
 	md.performer = tracker_coalesce (7,
 	                                 md.id3v24.performer1, md.id3v24.performer2,
@@ -2102,7 +2090,7 @@ extract_mp3 (const gchar          *uri,
 }
 
 TrackerExtractData *
-tracker_get_extract_data (void)
+tracker_extract_get_data (void)
 {
 	return extract_data;
 }
