@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2007, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2008, Nokia
@@ -27,14 +26,16 @@
 
 #include <string.h>
 #include <stdlib.h>
+
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <gio/gio.h>
 
 #include <totem-pl-parser.h>
+
 #include <libtracker-common/tracker-ontology.h>
 
-#include "tracker-main.h"
+#include <libtracker-extract/tracker-extract.h>
 
 #define PLAYLIST_PROPERTY_NO_TRACKS "entryCounter"
 #define PLAYLIST_PROPERTY_DURATION  "listDuration"
@@ -52,15 +53,14 @@
 #define RDF_TYPE RDF_PREFIX "type"
 
 typedef struct {
-	guint32     track_counter;
-	gint64      total_time;
-	TrackerSparqlBuilder   *metadata;
+	guint32 track_counter;
+	gint64 total_time;
+	TrackerSparqlBuilder *metadata;
 	const gchar *uri;
 } PlaylistMetadata;
 
-static void extract_playlist (const gchar *uri,
-                              TrackerSparqlBuilder   *metadata);
-
+static void extract_playlist (const gchar          *uri,
+                              TrackerSparqlBuilder *metadata);
 
 static TrackerExtractData playlist_data[] = {
 	{ "audio/x-mpegurl", extract_playlist },
@@ -89,6 +89,19 @@ entry_parsed (TotemPlParser *parser, const gchar *to_uri, GHashTable *to_metadat
 	tracker_sparql_builder_predicate (data->metadata, "a");
 	tracker_sparql_builder_object (data->metadata, "nfo:MediaFileListEntry");
 
+	/* The DO for the entries is needed for writeback, which depends on nie:isStoredAs
+	 * being set. You can see it as "is stored in" instead of as ;) */
+
+	tracker_sparql_builder_predicate (data->metadata, "a");
+	tracker_sparql_builder_object (data->metadata, "nie:DataObject");
+	tracker_sparql_builder_predicate (data->metadata, "a");
+	tracker_sparql_builder_object (data->metadata, "nie:InformationElement");
+
+	tracker_sparql_builder_predicate (data->metadata, "nie:isStoredAs");
+	tracker_sparql_builder_object_iri (data->metadata, data->uri);
+	tracker_sparql_builder_predicate (data->metadata, "nie:url");
+	tracker_sparql_builder_object_string (data->metadata, data->uri);
+
 	tracker_sparql_builder_predicate (data->metadata, "nfo:entryContent");
 	tracker_sparql_builder_object_unvalidated (data->metadata, to_uri);
 
@@ -130,6 +143,9 @@ extract_playlist (const gchar *uri,
 	tracker_sparql_builder_predicate (metadata, "a");
 	tracker_sparql_builder_object (metadata, "nfo:MediaList");
 
+	tracker_sparql_builder_predicate (metadata, "nie:isStoredAs");
+	tracker_sparql_builder_object_iri (metadata, uri);
+
 	result = totem_pl_parser_parse (pl, uri, FALSE);
 
 	switch (result) {
@@ -159,7 +175,7 @@ extract_playlist (const gchar *uri,
 }
 
 TrackerExtractData *
-tracker_get_extract_data (void)
+tracker_extract_get_data (void)
 {
 	return playlist_data;
 }
