@@ -37,10 +37,10 @@
 #include <libtracker-common/tracker-file-utils.h>
 #include <libtracker-common/tracker-utils.h>
 
-#include "tracker-main.h"
-#include "tracker-xmp.h"
-#include "tracker-iptc.h"
-#include "tracker-exif.h"
+#include <libtracker-extract/tracker-extract.h>
+#include <libtracker-extract/tracker-xmp.h>
+#include <libtracker-extract/tracker-iptc.h>
+#include <libtracker-extract/tracker-exif.h>
 
 #define EXIF_DATE_FORMAT        "%Y:%m:%d %H:%M:%S"
 
@@ -76,8 +76,8 @@ typedef struct {
 		*imagewidth, *imagelength, *make, *model, *orientation;
 } TiffData;
 
-static void extract_tiff (const gchar *filename,
-                          TrackerSparqlBuilder   *metadata);
+static void extract_tiff (const gchar          *filename,
+                          TrackerSparqlBuilder *metadata);
 
 static TrackerExtractData extract_data[] = {
 	{ "image/tiff", extract_tiff },
@@ -155,19 +155,19 @@ get_metering_mode (TIFF *image)
 	if (TIFFGetField (image, EXIFTAG_METERINGMODE, &varui16)) {
 		switch (varui16) {
 		case 1:
-			return g_strdup ("nmm:meteringMode-average");
+			return g_strdup ("nmm:metering-mode-average");
 		case 2:
-			return g_strdup ("nmm:meteringMode-center-weighted-average");
+			return g_strdup ("nmm:metering-mode-center-weighted-average");
 		case 3:
-			return g_strdup ("nmm:meteringMode-spot");
+			return g_strdup ("nmm:metering-mode-spot");
 		case 4:
-			return g_strdup ("nmm:meteringMode-multispot");
+			return g_strdup ("nmm:metering-mode-multispot");
 		case 5:
-			return g_strdup ("nmm:meteringMode-pattern");
+			return g_strdup ("nmm:metering-mode-pattern");
 		case 6:
-			return g_strdup ("nmm:meteringMode-partial");
+			return g_strdup ("nmm:metering-mode-partial");
 		default:
-			return g_strdup ("nmm:meteringMode-other");
+			return g_strdup ("nmm:metering-mode-other");
 		}
 	}
 
@@ -183,9 +183,9 @@ get_white_balance (TIFF *image)
 
 	if (TIFFGetField (image, EXIFTAG_WHITEBALANCE, &varui16)) {
 		if (varui16 == 0) {
-			return g_strdup ("nmm:whiteBalance-auto");
+			return g_strdup ("nmm:white-balance-auto");
 		}
-		return g_strdup ("nmm:whiteBalance-manual");
+		return g_strdup ("nmm:white-balance-manual");
 	}
 
 	return NULL;
@@ -304,10 +304,11 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 #ifdef HAVE_LIBIPTCDATA
 	if (TIFFGetField (image, TIFFTAG_RICHTIFFIPTC, &iptcSize, &iptcOffset)) {
 		if (TIFFIsByteSwapped(image) != 0)
-			TIFFSwabArrayOfLong((uint32 *) iptcOffset,(unsigned long) iptcSize);
-		tracker_read_iptc (iptcOffset,
-		                   4*iptcSize,
-		                   uri, &iptc_data);
+			TIFFSwabArrayOfLong((uint32 *) iptcOffset, (unsigned long) iptcSize);
+		tracker_iptc_read (iptcOffset,
+		                   4 * iptcSize,
+		                   uri, 
+		                   &iptc_data);
 	}
 #endif /* HAVE_LIBIPTCDATA */
 
@@ -315,7 +316,7 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 	   due to bugs in the original spec (type) */
 #ifdef HAVE_EXEMPI
 	if (TIFFGetField (image, TIFFTAG_XMLPACKET, &size, &xmpOffset)) {
-		tracker_read_xmp (xmpOffset,
+		tracker_xmp_read (xmpOffset,
 		                  size,
 		                  uri,
 		                  &xmp_data);
@@ -367,8 +368,8 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 	                                   tiff_data.model);
 
 	if (!merge_data.camera) {
-		merge_data.camera = tracker_merge (" ", 2, xmp_data.Make,
-		                                   xmp_data.Model);
+		merge_data.camera = tracker_merge (" ", 2, xmp_data.make,
+		                                   xmp_data.model);
 
 		if (!merge_data.camera) {
 			merge_data.camera = tracker_merge (" ", 2, exif_data.make,
@@ -378,21 +379,21 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 			g_free (exif_data.make);
 		}
 	} else {
-		g_free (xmp_data.Model);
-		g_free (xmp_data.Make);
+		g_free (xmp_data.model);
+		g_free (xmp_data.make);
 		g_free (exif_data.model);
 		g_free (exif_data.make);
 	}
 
 	merge_data.title = tracker_coalesce (5, tiff_data.documentname,
 	                                     xmp_data.title, 
-	                                     xmp_data.Title,
+	                                     xmp_data.title2,
 	                                     exif_data.document_name,
-	                                     xmp_data.PDFtitle);
+	                                     xmp_data.pdf_title);
 
 	merge_data.orientation = tracker_coalesce (4, tiff_data.orientation,
 	                                           exif_data.orientation,
-	                                           xmp_data.Orientation,
+	                                           xmp_data.orientation,
 	                                           iptc_data.image_orientation);
 
 	merge_data.copyright = tracker_coalesce (4, tiff_data.copyright,
@@ -401,47 +402,47 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 	                                         iptc_data.copyright_notice);
 
 	merge_data.white_balance = tracker_coalesce (2, exif_data.white_balance,
-	                                             xmp_data.WhiteBalance);
+	                                             xmp_data.white_balance);
 
 
 	merge_data.fnumber =  tracker_coalesce (2, exif_data.fnumber,
-	                                        xmp_data.FNumber);
+	                                        xmp_data.fnumber);
 
 	merge_data.flash =  tracker_coalesce (2, exif_data.flash,
-	                                      xmp_data.Flash);
+	                                      xmp_data.flash);
 
 	merge_data.focal_length =  tracker_coalesce (2, exif_data.focal_length,
-	                                             xmp_data.FocalLength);
+	                                             xmp_data.focal_length);
 
 	merge_data.artist =  tracker_coalesce (4, tiff_data.artist,
 	                                       exif_data.artist,
-	                                       xmp_data.Artist,
+	                                       xmp_data.artist,
 	                                       xmp_data.contributor);
 
 	merge_data.exposure_time =  tracker_coalesce (2, exif_data.exposure_time,
-	                                              xmp_data.ExposureTime);
+	                                              xmp_data.exposure_time);
 
 	merge_data.iso_speed_ratings =  tracker_coalesce (2, exif_data.iso_speed_ratings,
-	                                                  xmp_data.ISOSpeedRatings);
+	                                                  xmp_data.iso_speed_ratings);
 
 	merge_data.date =  tracker_coalesce (6, tiff_data.datetime,
 	                                     exif_data.time,
 	                                     xmp_data.date,
 	                                     iptc_data.date_created,
 	                                     exif_data.time_original,
-	                                     xmp_data.DateTimeOriginal);
+	                                     xmp_data.time_original);
 
 	merge_data.description = tracker_coalesce (3, tiff_data.imagedescription,
 	                                           exif_data.description,
 	                                           xmp_data.description);
 
 	merge_data.metering_mode =  tracker_coalesce (2, exif_data.metering_mode,
-	                                              xmp_data.MeteringMode);
+	                                              xmp_data.metering_mode);
 
-	merge_data.city = tracker_coalesce (2, iptc_data.city, xmp_data.City);
-	merge_data.state = tracker_coalesce (2, iptc_data.state, xmp_data.State);
-	merge_data.address = tracker_coalesce (2, iptc_data.sublocation, xmp_data.Address);
-	merge_data.country  = tracker_coalesce (2, iptc_data.countryname, xmp_data.Country);
+	merge_data.city = tracker_coalesce (2, iptc_data.city, xmp_data.city);
+	merge_data.state = tracker_coalesce (2, iptc_data.state, xmp_data.state);
+	merge_data.address = tracker_coalesce (2, iptc_data.sublocation, xmp_data.address);
+	merge_data.country  = tracker_coalesce (2, iptc_data.country_name, xmp_data.country);
 
 	merge_data.creator =  tracker_coalesce (3, iptc_data.byline,
 	                                        xmp_data.creator,
@@ -475,9 +476,9 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 		g_free (xmp_data.keywords);
 	}
 
-	if (xmp_data.PDFkeywords) {
-		insert_keywords (metadata, uri, xmp_data.PDFkeywords);
-		g_free (xmp_data.PDFkeywords);
+	if (xmp_data.pdf_keywords) {
+		insert_keywords (metadata, uri, xmp_data.pdf_keywords);
+		g_free (xmp_data.pdf_keywords);
 	}
 
 	if (xmp_data.subject) {
@@ -496,16 +497,6 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 		g_free (iptc_data.contact);
 	}
 
-	if (iptc_data.bylinetitle) {
-		tracker_sparql_builder_predicate (metadata, "nco:hasAffiliation");
-		tracker_sparql_builder_object_blank_open (metadata);
-		tracker_sparql_builder_predicate (metadata, "a");
-		tracker_sparql_builder_object (metadata, "nco:Affiliation");
-		tracker_sparql_builder_predicate (metadata, "nco:title");
-		tracker_sparql_builder_object_unvalidated (metadata, iptc_data.bylinetitle);
-		tracker_sparql_builder_object_blank_close (metadata);
-		g_free (iptc_data.bylinetitle);
-	}
 
 	if (xmp_data.publisher) {
 		tracker_sparql_builder_predicate (metadata, "nco:publisher");
@@ -699,21 +690,42 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 	}
 
 	if (merge_data.creator) {
-		tracker_sparql_builder_predicate (metadata, "nco:creator");
 
+		if (iptc_data.byline_title) {
+			tracker_sparql_builder_subject (metadata, "_:affiliation_by_line");
+			tracker_sparql_builder_predicate (metadata, "a");
+			tracker_sparql_builder_object (metadata, "nco:Affiliation");
+
+			tracker_sparql_builder_subject (metadata, "_:affiliation_by_line");
+			tracker_sparql_builder_predicate (metadata, "nco:title");
+			tracker_sparql_builder_object_unvalidated (metadata, iptc_data.byline_title);
+
+			tracker_sparql_builder_subject_iri (metadata, uri);
+		}
+
+		tracker_sparql_builder_predicate (metadata, "nco:creator");
 		tracker_sparql_builder_object_blank_open (metadata);
 		tracker_sparql_builder_predicate (metadata, "a");
 		tracker_sparql_builder_object (metadata, "nco:Contact");
-
 		tracker_sparql_builder_predicate (metadata, "nco:fullname");
 		tracker_sparql_builder_object_unvalidated (metadata, merge_data.creator);
+
+		if (iptc_data.byline_title) {
+			tracker_sparql_builder_predicate (metadata, "a");
+			tracker_sparql_builder_object (metadata, "nco:PersonContact");
+			tracker_sparql_builder_predicate (metadata, "nco:hasAffiliation");
+			tracker_sparql_builder_object (metadata, "_:affiliation_by_line");
+		}
+
 		tracker_sparql_builder_object_blank_close (metadata);
 		g_free (merge_data.creator);
 	}
+
+	g_free (iptc_data.byline_title);
 }
 
 TrackerExtractData *
-tracker_get_extract_data (void)
+tracker_extract_get_data (void)
 {
 	return extract_data;
 }
