@@ -20,8 +20,13 @@
 #include "config.h"
 
 #include <sys/statvfs.h>
+#include <fcntl.h>
+#include <sys/ioctl.h>
+#include <linux/msdos_fs.h>
+#include <unistd.h>
 
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 
 #include <libtracker-common/tracker-ontology.h>
 #include <libtracker-common/tracker-power.h>
@@ -34,7 +39,6 @@
 #include "tracker-miner-files.h"
 #include "tracker-config.h"
 #include "tracker-extract-client.h"
-#include "tracker-thumbnailer.h"
 #include "tracker-marshal.h"
 
 #define DISK_SPACE_CHECK_FREQUENCY 10
@@ -117,10 +121,6 @@ static void     low_disk_space_limit_cb       (GObject              *gobject,
                                                gpointer              user_data);
 
 static DBusGProxy * extractor_create_proxy    (void);
-static void    extractor_queue_thumbnail_cb   (DBusGProxy           *proxy,
-                                               const gchar          *filename,
-                                               const gchar          *mime_type,
-                                               gpointer              user_data);
 
 static gboolean miner_files_check_file        (TrackerMinerFS       *fs,
                                                GFile                *file);
@@ -209,21 +209,6 @@ tracker_miner_files_init (TrackerMinerFiles *mf)
 	/* Set up extractor and signals */
 	priv->extractor_proxy = extractor_create_proxy ();
 
-	dbus_g_object_register_marshaller (tracker_marshal_VOID__STRING_STRING,
-	                                   G_TYPE_NONE,
-	                                   G_TYPE_STRING,
-	                                   G_TYPE_STRING,
-	                                   G_TYPE_INVALID);
-
-	dbus_g_proxy_add_signal (priv->extractor_proxy, "QueueThumbnail",
-	                         G_TYPE_STRING,
-	                         G_TYPE_STRING,
-	                         G_TYPE_INVALID);
-
-	dbus_g_proxy_connect_signal (priv->extractor_proxy, "QueueThumbnail",
-	                             G_CALLBACK (extractor_queue_thumbnail_cb),
-	                             NULL, NULL);
-
 	init_mount_points (mf);
 }
 
@@ -276,10 +261,6 @@ miner_files_finalize (GObject *object)
 	mf = TRACKER_MINER_FILES (object);
 	priv = mf->private;
 
-	dbus_g_proxy_disconnect_signal (priv->extractor_proxy, "QueueThumbnail",
-	                                G_CALLBACK (extractor_queue_thumbnail_cb),
-	                                NULL);
-
 	g_object_unref (priv->extractor_proxy);
 
 	g_signal_handlers_disconnect_by_func (priv->config,
@@ -986,7 +967,7 @@ miner_files_check_file (TrackerMinerFS *fs,
 
 	should_process = TRUE;
 
- done:
+done:
 	g_free (basename);
 	g_free (path);
 
@@ -1007,6 +988,7 @@ miner_files_check_directory (TrackerMinerFS *fs,
 	gchar *basename;
 	gchar *path;
 	gboolean should_process;
+	gboolean is_hidden;
 
 	should_process = FALSE;
 	basename = NULL;
@@ -1019,7 +1001,32 @@ miner_files_check_directory (TrackerMinerFS *fs,
 
 	path = g_file_get_path (file);
 
-	if (file_info && g_file_info_get_is_hidden (file_info)) {
+	/* First we check the GIO hidden check. This does a number of
+	 * things for us which is good (like checking ".foo" dirs).
+	 */
+	is_hidden = file_info && g_file_info_get_is_hidden (file_info);
+
+	/* Second we check if the file is on FAT and if the hidden
+	 * attribute is set. GIO does this but ONLY on a Windows OS,
+	 * not for Windows files under a Linux OS, so we have to check
+	 * anyway.
+	 */
+	if (!is_hidden) {
+		int fd;
+
+		fd = g_open (path, O_RDONLY, 0);
+		if (fd != -1) {
+			__u32 attrs;
+
+			if (ioctl (fd, FAT_IOCTL_GET_ATTRIBUTES, &attrs) == 0) {
+				is_hidden = attrs & ATTR_HIDDEN ? TRUE : FALSE;
+			}
+
+			close (fd);
+		}
+	}
+
+	if (is_hidden) {
 		TrackerMinerFiles *mf;
 		GSList *allowed_directories;
 
@@ -1057,7 +1064,7 @@ miner_files_check_directory (TrackerMinerFS *fs,
 
 	basename = g_file_get_basename (file);
 
-	for (l = tracker_config_get_ignored_file_patterns (mf->private->config); l; l = l->next) {
+	for (l = tracker_config_get_ignored_directory_patterns (mf->private->config); l; l = l->next) {
 		if (g_pattern_match_string (l->data, basename)) {
 			goto done;
 		}
@@ -1215,15 +1222,6 @@ extractor_create_proxy (void)
 	return proxy;
 }
 
-static void
-extractor_queue_thumbnail_cb (DBusGProxy  *proxy,
-                              const gchar *filename,
-                              const gchar *mime_type,
-                              gpointer     user_data)
-{
-	tracker_thumbnailer_queue_add (filename, mime_type);
-}
-
 static void
 extractor_get_embedded_metadata_cb (DBusGProxy *proxy,
                                     gchar      *sparql,
@@ -1354,7 +1352,7 @@ process_file_cb (GObject      *object,
 
 	/* The URL of the DataObject (because IE = DO, this is correct) */
 	tracker_sparql_builder_predicate (sparql, "nie:url");
-	tracker_sparql_builder_object_iri (sparql, uri);
+	tracker_sparql_builder_object_string (sparql, uri);
 
 	tracker_sparql_builder_predicate (sparql, "nie:mimeType");
 	tracker_sparql_builder_object_string (sparql, mime_type);
@@ -1363,11 +1361,6 @@ process_file_cb (GObject      *object,
 
 	tracker_sparql_builder_insert_close (sparql);
 
-	/* Send file/mime data to thumbnailer (which adds it to the
-	 * queue if the thumbnailer handles those mime types).
-	 */
-	tracker_thumbnailer_queue_add (uri, mime_type);
-
 	/* Next step, getting embedded metadata */
 	extractor_get_embedded_metadata (data, uri, mime_type);
 
